# insightxnsdk

#### 介绍


#### 软件架构
软件架构说明


#### 安装教程

1.  安装
```shell script
pip3 install insightxnsdk -i https://mirrors.aliyun.com/pypi/simple
```

2.  xxxx
3.  xxxx

#### 使用说明

1.  xxxx
2.  xxxx
3.  xxxx

